@@ -38,10 +38,10 @@ metadata_my_xfailed_test, _ = m.SuiteMetadata.objects.get_or_create(kind='test',
 metadata_my_skipped_test, _ = m.SuiteMetadata.objects.get_or_create(kind='test', suite=suite.slug, name='my_skipped_test')
 
 testrun = build.test_runs.create(environment=environment)
-passed_test = testrun.tests.create(suite=suite, result=True, metadata=metadata_my_passed_test)
-failed_test = testrun.tests.create(suite=suite, result=False, metadata=metadata_my_failed_test)
-xfailed_test = testrun.tests.create(suite=suite, result=True, metadata=metadata_my_xfailed_test, has_known_issues=True)
-skipped_test = testrun.tests.create(suite=suite, result=None, metadata=metadata_my_skipped_test)
+passed_test = testrun.tests.create(suite=suite, result=True, metadata=metadata_my_passed_test, build=testrun.build, environment=testrun.environment)
+failed_test = testrun.tests.create(suite=suite, result=False, metadata=metadata_my_failed_test, build=testrun.build, environment=testrun.environment)
+xfailed_test = testrun.tests.create(suite=suite, result=True, metadata=metadata_my_xfailed_test, has_known_issues=True, build=testrun.build, environment=testrun.environment)
+skipped_test = testrun.tests.create(suite=suite, result=None, metadata=metadata_my_skipped_test, build=testrun.build, environment=testrun.environment)
 
 RecordTestRunStatus()(testrun)
 
